@@ -1,7 +1,12 @@
+from armstrong.utils.backends import GenericBackend, DID_NOT_HANDLE
 from django.contrib.gis.db import models
+from django.core.exceptions import ImproperlyConfigured
 
 from .constants import TYPE_CHOICES, STATUS_CHOICES
 
+# A generic backend that defines a method `get_representative(self, district)`
+representative_backend = GenericBackend("TX_REPRESENTATIVE_BACKENDS")
+
 
 class DistrictManager(models.GeoManager):
     def filter_by_lat_lng(self, lat, lng):
@@ -27,3 +32,11 @@ class District(models.Model):
     class Meta:
         unique_together = ('type', 'number', 'year')
         ordering = ('type', 'number')
+
+    @property
+    def representative(self):
+        try:
+            backend = representative_backend.get_backend()
+            return backend.get_representative(self)
+        except (ImproperlyConfigured, DID_NOT_HANDLE):
+            return None
